# BioRED

***Briefings in Bioinformatics*, Volume 23, Issue 5**: [BioRED: a rich biomedical relation extraction dataset](https://doi.org/10.1093/bib/bbac282)

**GitHub**: [`ncbi/BioRED`](https://github.com/ncbi/BioRED)

[**Annotation Guideline**](https://ftp.ncbi.nlm.nih.gov/pub/lu/BioRED/BioRED_Annotation_Guideline.pdf)
